@@ -38,33 +38,14 @@ class CTool():
 
     # 水体提取
     @classmethod
-    def extract(cls, tifDir, sampleType, tempDir, outDir, type):
-        print(f"tif:{tifDir},sampleType:{sampleType},tempDir:{tempDir},outDir:{outDir},type:{type}")
-        if type == "sentinel2" or type == "GF1_wfv":
-            if not os.path.exists(tempDir):
-                os.mkdir(tempDir)
-            else:
-                shutil.rmtree(tempDir)
-                os.mkdir(tempDir)
-            WaterExtract.GF1_wfv(tifDir, sampleType, tempDir, outDir)
-
-        elif type == "Landsat8":
-            classs = os.listdir(tifDir)
-            for idx, folder in enumerate(classs):
-                ori_landsat = os.path.join(tifDir, folder)
-                path1 = WaterExtract.band_merge(ori_landsat, outDir)
-                WaterExtract.landset8(path1, sampleType,  tempDir, outDir)
-
-        elif type == "div_deal":
-            if not os.path.exists(tempDir):
-                os.mkdir(tempDir)
-            else:
-                shutil.rmtree(tempDir)
-                os.mkdir(tempDir)
-            WaterExtract.GF1(tifDir, sampleType, tempDir, outDir)
-
+    def extract(cls, tifDir, sampleType, tempDir, outDir):
+        if not os.path.exists(tempDir):
+            os.mkdir(tempDir)
         else:
-            print("输入参数有误，请退出重新执行")
+            shutil.rmtree(tempDir)
+            os.mkdir(tempDir)
+        WaterExtract.GF1_wfv(tifDir, sampleType, tempDir, outDir)
+
 
     # Landsat8遥感影像下载
     @classmethod
